==> qtjambi-network-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiNetwork/QDnsDomainNameRecord_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtnetwork-config.h>
#if QT_CONFIG(dnslookup)
#include <QtNetwork/qdnslookup.h>
#endif //QT_CONFIG(dnslookup)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(dnslookup)


void deleter_QDnsDomainNameRecord(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDnsDomainNameRecord")
    QDnsDomainNameRecord *_ptr = reinterpret_cast<QDnsDomainNameRecord *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(dnslookup)

// emitting (writeConstructors)
// new QDnsDomainNameRecord()
void __qt_construct_QDnsDomainNameRecord_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsDomainNameRecord()")
#if QT_CONFIG(dnslookup)
    Q_UNUSED(__java_arguments)
    QDnsDomainNameRecord *__qt_this = new(__qtjambi_ptr) QDnsDomainNameRecord();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// new QDnsDomainNameRecord(QDnsDomainNameRecord)
void __qt_construct_QDnsDomainNameRecord_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsDomainNameRecord(QDnsDomainNameRecord)")
#if QT_CONFIG(dnslookup)
    jobject other0 = __java_arguments[0].l;
    const QDnsDomainNameRecord& __qt_other0 = qtjambi_cast<const QDnsDomainNameRecord& >(__jni_env, other0);
    QDnsDomainNameRecord *__qt_this = new(__qtjambi_ptr) QDnsDomainNameRecord(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// destruct QDnsDomainNameRecord
void __qt_destruct_QDnsDomainNameRecord(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDnsDomainNameRecord")

#if QT_CONFIG(dnslookup)

    reinterpret_cast<QDnsDomainNameRecord*>(ptr)->~QDnsDomainNameRecord();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(dnslookup)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDnsDomainNameRecord::QDnsDomainNameRecord()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_initialize_1native__Lio_qt_network_QDnsDomainNameRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsDomainNameRecord::QDnsDomainNameRecord()")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsDomainNameRecord_0, sizeof(QDnsDomainNameRecord), typeid(QDnsDomainNameRecord), false, &deleter_QDnsDomainNameRecord, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsDomainNameRecord::QDnsDomainNameRecord(QDnsDomainNameRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_initialize_1native__Lio_qt_network_QDnsDomainNameRecord_2Lio_qt_network_QDnsDomainNameRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsDomainNameRecord::QDnsDomainNameRecord(QDnsDomainNameRecord)")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsDomainNameRecord_1, sizeof(QDnsDomainNameRecord), typeid(QDnsDomainNameRecord), false, &deleter_QDnsDomainNameRecord, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsDomainNameRecord::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsDomainNameRecord::operator=(QDnsDomainNameRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_assign_1native_1cref_1QDnsDomainNameRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::operator=(QDnsDomainNameRecord)", __qt_this)
        const QDnsDomainNameRecord& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDnsDomainNameRecord>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsDomainNameRecord::swap(QDnsDomainNameRecord&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_swap_1native_1ref_1QDnsDomainNameRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::swap(QDnsDomainNameRecord&)", __qt_this)
        QDnsDomainNameRecord& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDnsDomainNameRecord>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsDomainNameRecord::timeToLive()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_timeToLive_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::timeToLive()const", __qt_this)
        quint32 __qt_return_value = __qt_this->timeToLive();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsDomainNameRecord::value()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::value()const", __qt_this)
        QString __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(dnslookup)

        const QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(dnslookup)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDnsDomainNameRecord(){
    using namespace RegistryAPI;

#if QT_CONFIG(dnslookup)

    const std::type_info& typeId = registerValueTypeInfo<QDnsDomainNameRecord>("QDnsDomainNameRecord", "io/qt/network/QDnsDomainNameRecord");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDnsDomainNameRecord, {
        ConstructorInfo(&__qt_construct_QDnsDomainNameRecord_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDnsDomainNameRecord_1, "Lio/qt/network/QDnsDomainNameRecord;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDnsDomainNameRecord);
    registerMetaType<QDnsDomainNameRecord>("QDnsDomainNameRecord");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(dnslookup)

}

==> qtjambi-network-debuginfo-windows-x64-6.7.2.jar: sources/QtJambiNetwork/QDnsDomainNameRecord_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtnetwork-config.h>
#if QT_CONFIG(dnslookup)
#include <QtNetwork/qdnslookup.h>
#endif //QT_CONFIG(dnslookup)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(dnslookup)


void deleter_QDnsDomainNameRecord(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDnsDomainNameRecord")
    QDnsDomainNameRecord *_ptr = reinterpret_cast<QDnsDomainNameRecord *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(dnslookup)

// emitting (writeConstructors)
// new QDnsDomainNameRecord()
void __qt_construct_QDnsDomainNameRecord(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsDomainNameRecord()")
#if QT_CONFIG(dnslookup)
    Q_UNUSED(__java_arguments)
    QDnsDomainNameRecord *__qt_this = new(__qtjambi_ptr) QDnsDomainNameRecord();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// QDnsDomainNameRecord::QDnsDomainNameRecord()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_initialize_1native__Lio_qt_network_QDnsDomainNameRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsDomainNameRecord::QDnsDomainNameRecord()")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsDomainNameRecord, sizeof(QDnsDomainNameRecord), typeid(QDnsDomainNameRecord), 0, false, &deleter_QDnsDomainNameRecord, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDnsDomainNameRecord(QDnsDomainNameRecord)
void __qt_construct_QDnsDomainNameRecord_cref_QDnsDomainNameRecord(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsDomainNameRecord(QDnsDomainNameRecord)")
#if QT_CONFIG(dnslookup)
    jobject other0 = __java_arguments[0].l;
    const QDnsDomainNameRecord& __qt_other0 = qtjambi_cast<const QDnsDomainNameRecord&>(__jni_env, other0);
    QDnsDomainNameRecord *__qt_this = new(__qtjambi_ptr) QDnsDomainNameRecord(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// QDnsDomainNameRecord::QDnsDomainNameRecord(QDnsDomainNameRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_initialize_1native__Lio_qt_network_QDnsDomainNameRecord_2Lio_qt_network_QDnsDomainNameRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsDomainNameRecord::QDnsDomainNameRecord(QDnsDomainNameRecord)")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsDomainNameRecord_cref_QDnsDomainNameRecord, sizeof(QDnsDomainNameRecord), typeid(QDnsDomainNameRecord), 0, false, &deleter_QDnsDomainNameRecord, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDnsDomainNameRecord
void __qt_destruct_QDnsDomainNameRecord(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDnsDomainNameRecord")

#if QT_CONFIG(dnslookup)

    reinterpret_cast<QDnsDomainNameRecord*>(ptr)->~QDnsDomainNameRecord();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(dnslookup)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDnsDomainNameRecord::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::name()const", __this_nativeId)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsDomainNameRecord::operator=(QDnsDomainNameRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_assign_1native_1cref_1QDnsDomainNameRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::operator=(QDnsDomainNameRecord)", __this_nativeId)
        const QDnsDomainNameRecord& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDnsDomainNameRecord>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsDomainNameRecord::swap(QDnsDomainNameRecord&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_swap_1native_1ref_1QDnsDomainNameRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::swap(QDnsDomainNameRecord&)", __this_nativeId)
        QDnsDomainNameRecord& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDnsDomainNameRecord>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsDomainNameRecord::timeToLive()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_timeToLive_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::timeToLive()const", __this_nativeId)
        quint32 __qt_return_value = __qt_this->timeToLive();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsDomainNameRecord::value()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsDomainNameRecord::value()const", __this_nativeId)
        QString __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsDomainNameRecord_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(dnslookup)

        const QDnsDomainNameRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsDomainNameRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(dnslookup)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDnsDomainNameRecord(){
    using namespace RegistryAPI;

#if QT_CONFIG(dnslookup)

    const std::type_info& typeId = registerValueTypeInfo<QDnsDomainNameRecord>("QDnsDomainNameRecord", "io/qt/network/QDnsDomainNameRecord");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDnsDomainNameRecord, {
        ConstructorInfo(&__qt_construct_QDnsDomainNameRecord, nullptr)
       ,ConstructorInfo(&__qt_construct_QDnsDomainNameRecord_cref_QDnsDomainNameRecord, "Lio/qt/network/QDnsDomainNameRecord;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDnsDomainNameRecord);
    registerMetaType<QDnsDomainNameRecord>("QDnsDomainNameRecord");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(dnslookup)

}
